@@ -11,7 +11,7 @@ use SQL::Abstract;
 our $sql = SQL::Abstract->new;
 use vars qw/$sql/;
 
-our $VERSION = '0.02';
+our $VERSION = '0.04';
 
 =head2 count
 
@@ -25,6 +25,20 @@ sub count {
     return scalar @{$self->{result}};
 }
 
+=head2 all
+
+Returns all rows in a table as a resultset
+
+    my $rs = $schema->resultset('Users')->all;
+
+=cut
+
+sub all {
+    my $self = shift;
+
+    return $self->search([], {});
+}
+
 =head2 first
 
 Get the first result from a resultset
@@ -37,6 +51,18 @@ sub first {
     return bless $self->{result}->[0], $self->{r};
 }
 
+=head2 last
+
+Get the last result from a resultset
+
+=cut
+
+sub last {
+    my $self = shift;
+
+    return bless $self->{result}->[ scalar(@{$self->{result}}-1) ], $self->{r};
+}
+
 =head2 next
 
 A simple iterator to loop through a resultset. Each 
@@ -67,16 +93,16 @@ sub next {
         delete $self->{_it_max};
         return undef;
     }
-    my $rs = {
-        dbh    => $self->{dbh},
-        result => $self->{result}->[$pos], 
-        table  => $self->{table},
-        primary_key => $self->{primary_key},
-        r => $self->{r},
-        rs => $self->{rs},
-    };
+    #my $rs = {
+    #    dbh    => $self->{dbh},
+    #    result => $self->{result}->[$pos]->[0], 
+    #    table  => $self->{table},
+    #    primary_key => $self->{primary_key},
+    #    r => $self->{r},
+    #    rs => $self->{rs},
+    #};
     #return $self->{result}->[$pos];
-    return bless $rs, $self->{r};
+    return bless $self->{result}->[$pos], $self->{r};
 }
 
 =head2 primary_key
@@ -143,20 +169,21 @@ sub find {
     if (scalar @$fields == 0) { push @$fields, '*'; }
     my ($stmt, @bind) = $sql->select($self->{table}, $fields, $c);
     my ($wstmt, @wbind) = $sql->where($c);
-    my $r = {
-        dbh    => $self->{dbh},
-        result => $self->{dbh}->selectall_arrayref($stmt, { Slice => {} }, @bind)->[0],
-        stmt   => $wstmt,
-        bind   => \@wbind,
-        #where  => $sql->generate('where', $c),
-        where  => $c,
-        table  => $self->{table},
-        primary_key => $self->{primary_key},
-        r       => $self->{r},
-        rs      => $self->{rs},
-    };
+#    my $r = {
+#        dbh    => $self->{dbh},
+#        result => $self->{dbh}->selectall_arrayref($stmt, { Slice => {} }, @bind)->[0],
+#        stmt   => $wstmt,
+#        bind   => \@wbind,
+#        #where  => $sql->generate('where', $c),
+#        where  => $c,
+#        table  => $self->{table},
+#        primary_key => $self->{primary_key},
+#        r       => $self->{r},
+#        rs      => $self->{rs},
+#    };
 
-    return bless $r, $self->{r};
+    my $result = $self->{dbh}->selectall_arrayref($stmt, { Slice => {} }, @bind)->[0];
+    return bless $result, $self->{r};
 }
 
 =head2 insert
